pub struct WirePosition {
pub line: u32,
pub character: u32,
}Expand description
A protocol-facing LSP position.
Both fields are 0-based. character is measured in UTF-16 code units.
Fields
line: u32Zero-based line number.
character: u32Zero-based UTF-16 code-unit offset within the line.
Implementations
Sourceimpl WirePosition
impl WirePosition
Sourcepub fn new(line: u32, character: u32) -> Self
pub fn new(line: u32, character: u32) -> Self
Creates a new wire position from explicit line and character values.
Sourcepub fn from_byte_offset(source: &str, byte_offset: usize) -> Self
pub fn from_byte_offset(source: &str, byte_offset: usize) -> Self
Converts a byte offset in source into an LSP wire position.
Sourcepub fn to_byte_offset(&self, source: &str) -> usize
pub fn to_byte_offset(&self, source: &str) -> usize
Converts this LSP wire position back into a byte offset in source.